setwd("D:/Additional_projects/HaukeKegler/")

# plot sampling area for small scale paper
# 2 panel map:
# left: Spermonde large with subplot Indonesia
# right: BL and KK map

load("Spermonde_map_small_scale.Rdata")
# save.image("Spermonde_map_small_scale.Rdata")

### reading data ####
# maps in R can be generated using the normal plot() function
# here we will produce a large-scale and zoom-in map of the sampling area for the vent data set
# thanks to Pier Buttigieg for parts of the code

require(sp)
require(maps)
# require(Hmisc)
require(raster)
require(rgeos)
require(rgdal)
require(TeachingDemos)
require(scales)

# download coastlines/country borders at: http://www.gadm.org/country
idnAdm0 <- readRDS("IDN_adm0.rds")
pngAdm0 <- readRDS("PNG_adm0.rds")
mysAdm0 <- readRDS("MYS_adm0.rds")
brnAdm0 <- readRDS("BRN_adm0.rds")
thaAdm0 <- readRDS("THA_adm0.rds")

# read shape files for isalnds and reef
BL.island <- readOGR(dsn = "Small scale transects/B_Lompo Island.shp", layer = "B_Lompo Island")
BL.reef <- readOGR(dsn = "Small scale transects/B_Lompo Reef.shp", layer = "B_Lompo Reef")
KK.island <- readOGR(dsn = "Small scale transects/Keke island.shp", layer = "Keke island")
KK.reef <- readOGR(dsn = "Small scale transects/Keke reef.shp", layer = "Keke reef")
BC.reef <- readOGR(dsn = "Bara Caddi.kml", layer = "Bara Caddi.kml")

summary(BL.reef)$bbox
summary(KK.reef)$bbox

# coordinates of transect points
transect <- read.table("Small_scale_metadata.csv", h = T, sep = ";")
range(transect$Longitude)
range(transect$Latitude)
transect$color <- c(rep("red", 4), rep("blue", 4), rep("green", 4), rep("orange", 4))

# define areas of interest
# subplot of Indonesia
ind.xmin <- 95
ind.xmax <- 142
ind.ymin <- -12
ind.ymax <- 7
ind.plot.ratio <- (ind.ymax - ind.ymin) / (ind.xmax - ind.xmin)

# left panel Spermonde
spe.xmin <- 118.9
spe.xmax <- 119.7
spe.ymin <- -5.4
spe.ymax <- -4.4
spe.plot.ratio <- (spe.ymax - spe.ymin) / (spe.xmax - spe.xmin)

# right panel BL and KK
small.xmin <- 119.2772
small.xmax <- 119.3388
small.ymin <- -5.114
small.ymax <- -5.037
small.plot.ratio <- (small.ymax - small.ymin) / (small.xmax - small.xmin)
# mean(c(small.xmin, small.xmax)) - ((small.ymax - small.ymin) / spe.plot.ratio / 2)
# mean(c(small.xmin, small.xmax)) + ((small.ymax - small.ymin) / spe.plot.ratio / 2)

# crop to area of interest
# subplot of Indonesia
idnAdm0.ind <- crop(idnAdm0, extent(ind.xmin, ind.xmax, ind.ymin, ind.ymax))
pngAdm0.ind <- crop(pngAdm0, extent(ind.xmin, ind.xmax, ind.ymin, ind.ymax))
mysAdm0.ind <- crop(mysAdm0, extent(ind.xmin, ind.xmax, ind.ymin, ind.ymax))
brnAdm0.ind <- crop(brnAdm0, extent(ind.xmin, ind.xmax, ind.ymin, ind.ymax))
thaAdm0.ind <- crop(thaAdm0, extent(ind.xmin, ind.xmax, ind.ymin, ind.ymax))

# left panel: Spermonde
idnAdm0.spe <- crop(idnAdm0, extent(spe.xmin, spe.xmax, spe.ymin, spe.ymax))

# right panel: BL and KK
idnAdm0.small <- crop(idnAdm0, extent(small.xmin, small.xmax, small.ymin, small.ymax))

### PLOT ###
# open new graphics device
pdf("Spermonde_small_scale.pdf", height = 3.5 * spe.plot.ratio, width = 7)
# layout(matrix(c(1, 2), 1, 2), widths = c(1, 1))
par(
  mfrow = c(1, 2),
  mar = c(1 * spe.plot.ratio, 1, 1 * spe.plot.ratio, 1), 
  xaxs="i", 
  yaxs="i",
  xpd = F
)


### Spermonde ####
plot(
  idnAdm0, # country borders
  col = "gray77", # 'land' color
  border = "gray52", # 'land' border
  xlim = c(spe.xmin, spe.xmax),
  ylim = c(spe.ymin, spe.ymax),
  asp = 1, # aspect ratio
  lwd = 0.5
)

par(xpd = NA)
text(
  par("usr")[1] - (par("usr")[2] - par("usr")[1]) * 0.02, 
  par("usr")[4] + (par("usr")[4] - par("usr")[3]) * 0.02, 
  labels = "(A)", 
  cex = 0.8, 
  font = 2
)
par(xpd = F)

# add axes
axis(
  1, 
  tck = 0.01, # length of ticks, draw inside plot
  mgp = c(1,-1.2,0), # margin lines for the axis title, tick labels and axis line, plot ticks inside plot
  cex.axis = 0.5, # size of tick labels
  at = seq( # position of tick labels
    round(spe.xmin, 1) + 0.1, 
    round(spe.xmax, 1) - 0.1, 
    0.2
  ), 
  labels = paste( # tick labels
    format(
      seq( 
        round(spe.xmin, 1) + 0.1, 
        round(spe.xmax, 1) - 0.1, 
        0.2
      ), 
      nsmall = 1
    ), 
    "", 
    sep = ""
  ), 
  lwd = 0.5
)
axis(
  2, 
  tck = 0.01, 
  mgp = c(1,-0.5,0), 
  cex.axis = 0.5, 
  las = 2,
  at = seq( # position of tick labels
    round(spe.ymin, 1) + 0.1, 
    round(spe.ymax, 1) - 0.1, 
    0.2
  ), 
  labels = paste( # tick labels
    format(
      seq( 
        round(spe.ymin, 1) + 0.1, 
        round(spe.ymax, 1) - 0.1, 
        0.2
      ), 
      nsmall = 1
    ), 
    "", 
    sep = ""
  ), 
  hadj = 0, # align right (horizontal labels)
  lwd = 0.5
)

# add axis titles
mtext(
  side = 1, # below plot (x-axis)
  text = "Longitude", # title
  line = 0, # margin line
  cex = 0.7
)
mtext(
  side = 2, # left of plot (y-axis)
  text = "Latitude", 
  line = 0,
  cex = 0.7
)

# location of Makassar
points(119.4319400, -5.1486100, pch = 16, cex = 2)
text(119.4319400, -5.1486100, labels = "Makassar", pos = 1, cex = 0.8, font = 2)

### Indonesia ####
# clean area for new plot
subplot.ymin <- -4.6
rect(
  spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), 
  -4.6, 
  spe.xmax, 
  spe.ymax, 
  col = "white",
  border = NA, 
  lwd = 0.5
)

# add larger map
# Papua New Guinea
subplot(
  plot(
    pngAdm0.ind, # country borders
    col = "gray77", # 'land' color
    border = "gray52", # 'land' border
    xlim = c(ind.xmin, ind.xmax),
    ylim = c(ind.ymin, ind.ymax),
    asp = 1, # aspect ratio
    lwd = 0.5
  ),
  x = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax),
  y = c(subplot.ymin, spe.ymax),
  pars = list(mar = c(0, 0, 0, 0), xaxs="i", yaxs="i", xpd = F)
)
# Thailand
subplot(
  plot(
    thaAdm0.ind, # country borders
    col = "gray77", # 'land' color
    border = "gray52", # 'land' border
    xlim = c(ind.xmin, ind.xmax),
    ylim = c(ind.ymin, ind.ymax),
    asp = 1, # aspect ratio
    lwd = 0.5
  ),
  x = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax),
  y = c(subplot.ymin, spe.ymax),
  pars = list(mar = c(0, 0, 0, 0), xaxs="i", yaxs="i", xpd = F)
)
# Malaysia
subplot(
  plot(
    mysAdm0.ind, # country borders
    col = "gray77", # 'land' color
    border = "gray52", # 'land' border
    xlim = c(ind.xmin, ind.xmax),
    ylim = c(ind.ymin, ind.ymax),
    asp = 1, # aspect ratio
    lwd = 0.5
  ),
  x = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax),
  y = c(subplot.ymin, spe.ymax),
  pars = list(mar = c(0, 0, 0, 0), xaxs="i", yaxs="i", xpd = F)
)
# Brunei
subplot(
  plot(
    brnAdm0.ind, # country borders
    col = "gray77", # 'land' color
    border = "gray52", # 'land' border
    xlim = c(ind.xmin, ind.xmax),
    ylim = c(ind.ymin, ind.ymax),
    asp = 1, # aspect ratio
    lwd = 0.5
  ),
  x = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax),
  y = c(subplot.ymin, spe.ymax),
  pars = list(mar = c(0, 0, 0, 0), xaxs="i", yaxs="i", xpd = F)
)
# Indonesia
subplot(
  plot(
    idnAdm0.ind, # country borders
    col = "gray77", # 'land' color
    border = "gray52", # 'land' border
    xlim = c(ind.xmin, ind.xmax),
    ylim = c(ind.ymin, ind.ymax),
    asp = 1, # aspect ratio
    lwd = 0.5
  ),
  x = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax),
  y = c(subplot.ymin, spe.ymax),
  pars = list(mar = c(0, 0, 0, 0), xaxs="i", yaxs="i", xpd = F)
)

# rescale position of Makassar
subplot.makassar.x <- rescale(119.4319400, from = c(ind.xmin, ind.xmax), to = c(spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), spe.xmax))
subplot.makassar.y <- rescale(-5.1486100, from = c(ind.ymin, ind.ymax), to = c(subplot.ymin, spe.ymax))
points(
  subplot.makassar.x, 
  subplot.makassar.y, 
  pch = 16, 
  cex = 0.8
)
arrows(
  subplot.makassar.x - 0.1, # beginning of arrow (x)
  subplot.makassar.y, # beginning of arrow (y)
  subplot.makassar.x - 0.02, # end of arrow (x)
  subplot.makassar.y, # end of arrow (y)
  length = 0.08, # length of the "arrow roof"
  angle = 30, # angle of the "arrow roof"
  col = "black", # colour of arrow
  lwd = 2
)

# box around subplot
rect(
  spe.xmax - ((spe.ymax - subplot.ymin) / ind.plot.ratio), 
  subplot.ymin, 
  spe.xmax, 
  spe.ymax, 
  col = NA,
  border = "black", 
  lwd = 0.5
)

### scale bar, north arrow Spermonde, zoom-in box BL and KK ####
# draw box around plotting large area
box(
  which = "plot", 
  lty = "solid",
  lwd = 0.5
)

# add scale bar
map.scale2 <- function (x, y, relwidth = 0.15, metric = TRUE, ratio = TRUE, 
                        ...) 
{
  format.pretty <- function(x, digits = 2) {
    x = signif(x, 2)
    prettyNum(formatC(x, format = "fg", digits = digits), 
              big.mark = ",")
  }
  usr <- par("usr")
  if (missing(y)) 
    y <- (9 * usr[3] + usr[4])/10
  if (abs(y) >= 90) 
    warning("location of scale out of this world!")
  if (missing(x)) 
    x <- (9 * usr[1] + usr[2])/10
  cosy <- cos((2 * pi * y)/360)
  perdeg <- (2 * pi * (6356.78 + 21.38 * cosy) * cosy)/360
  scale <- (perdeg * 1e+05)/(2.54 * (par("pin")/diff(par("usr"))[-2])[1])
  if (metric) 
    unit <- "km"
  else {
    perdeg <- perdeg * 0.6213712
    unit <- "mi"
  }
  len <- perdeg * relwidth * (usr[2] - usr[1])
  ats <- pretty(c(0, len), n = 2)
  nats <- length(ats)
  labs <- as.character(ats)
  labs[nats] <- paste(labs[nats], unit)
  linexy <- matrix(NA, ncol = 2, nrow = 3 * nats)
  colnames(linexy) <- c("x", "y")
  cxy <- par("cxy")
  dy <- cxy[2] * par("tcl")
  dx <- ats[nats]/perdeg/(nats - 1)
  linexy[1, ] <- c(x, y)
  linexy[2, ] <- c(x, y + dy)
  for (i in 1:(nats - 1)) {
    linexy[3 * i, ] <- c(x + (i - 1) * dx, y)
    linexy[3 * i + 1, ] <- c(x + i * dx, y)
    linexy[3 * i + 2, ] <- c(x + i * dx, y + dy)
  }
  lines(linexy, ...)
  text(x + ats/perdeg, y + dy - 0.5 * cxy[2], labs, adj = c(0.4, 
                                                            0.5), ...)
  if (ratio) 
    text(x, y + 0.5 * cxy[2], paste("scale approx 1:", format.pretty(scale), 
                                    sep = ""), adj = 0, ...)
  invisible(scale)
}

map.scale2(
  119.05, # position (x)
  -5.25, # position (y)
  relwidth = 0.2, # proportion of width of display to be used for the scale
  metric = TRUE, # units in km
  ratio = FALSE, # don't display scale ratio of map
  cex = 0.5, # size of labels
  lwd = 0.5
)

# add north arrow
arrows(
  119.05, # beginning of arrow (x)
  -4.6, # beginning of arrow (y)
  119.05, # end of arrow (x)
  -4.5, # end of arrow (y)
  length = 0.08, # length of the "arrow roof"
  angle = 30, # angle of the "arrow roof"
  col = "black" # colour of arrow
)
text(119.05, -4.55, "N", font = 1, cex = 0.8, col = "black")

# add zoom-in box for detailed plot
rect(
  small.xmin, 
  small.ymin, 
  small.xmax, 
  small.ymax, 
  col = NA,
  border = "black", 
  lwd = 0.5
)

text(
  c(max(transect$Longitude[transect$Island == "Barrang Lompo"]), max(transect$Longitude[transect$Island == "K. Keke"])),
  c(mean(transect$Latitude[transect$Island == "Barrang Lompo"]), mean(transect$Latitude[transect$Island == "K. Keke"])),
  labels = c("Barrang Lompo", "Kodinggareng Keke"),
  cex = 0.5,
  pos = c(4, 2),
  font = 2
)

### BL and KK plot ####
plot(
  BC.reef, # country borders
  col = "gray90", # 'reef' color
  border = NA,
  xlim = c(small.xmin, small.xmax),
  ylim = c(small.ymin, small.ymax),
  asp = 1, # aspect ratio
  lwd = 0.5
)
plot(
  idnAdm0.small,
  col = "gray77", # 'land' color
  border = "gray52",
  add = T,
  lwd = 0.5
)
plot(
  KK.reef,
  col = "gray90", # 'reef' color
  border = NA,
  add = T
)
plot(
  BL.reef,
  col = "gray90", # 'reef' color
  border = NA,
  add = T
)
plot(
  KK.island,
  col = "gray77", # 'land' color
  border = "gray52",
  add = T,
  lwd = 0.5
)
plot(
  BL.island,
  col = "gray77", # 'land' color
  border = "gray52",
  add = T,
  lwd = 0.5
)

par(xpd = NA)
text(
  par("usr")[1] - (par("usr")[2] - par("usr")[1]) * 0.02, 
  par("usr")[4] + (par("usr")[4] - par("usr")[3]) * 0.02, 
  labels = "(B)", 
  cex = 0.8, 
  font = 2
)
par(xpd = F)

# add axes
axis(
  1, 
  tck = 0.01, # length of ticks, draw inside plot
  mgp = c(1,-1.2,0), # margin lines for the axis title, tick labels and axis line, plot ticks inside plot
  cex.axis = 0.5, # size of tick labels
  at = seq( # position of tick labels
    round(small.xmin, 2) + 0.01, 
    round(small.xmax, 2) - 0.01, 
    0.02
  ), 
  labels = paste( # tick labels
    format(
      seq( 
        round(small.xmin, 2) + 0.01, 
        round(small.xmax, 2) - 0.01, 
        0.02
      ), 
      nsmall = 1
    ), 
    "", 
    sep = ""
  ), 
  lwd = 0.5
)
axis(
  2, 
  tck = 0.01, 
  mgp = c(1,-0.5,0), 
  cex.axis = 0.5, 
  las = 2,
  at = seq( # position of tick labels
    round(small.ymin, 2) + 0.01, 
    round(small.ymax, 2) - 0.01, 
    0.02
  ), 
  labels = paste( # tick labels
    format(
      seq( 
        round(small.ymin, 2) + 0.01, 
        round(small.ymax, 2) - 0.01, 
        0.02
      ), 
      nsmall = 1
    ), 
    "", 
    sep = ""
  ), 
  hadj = 0, # align right (horizontal labels)
  lwd = 0.5
)

# add axis titles
mtext(
  side = 1, # below plot (x-axis)
  text = "Longitude", # title
  line = 0, # margin line
  cex = 0.7
)
mtext(
  side = 2, # left of plot (y-axis)
  text = "Latitude", 
  line = 0,
  cex = 0.7
)

box(
  which = "plot", 
  lty = "solid",
  lwd = 0.5
)

map.scale2(
  119.285, # position (x)
  -5.045, # position (y)
  relwidth = 0.2, # proportion of width of display to be used for the scale
  metric = TRUE, # units in km
  ratio = FALSE, # don't display scale ratio of map
  cex = 0.5, # size of labels
  lwd = 0.5
)

# transect points
points(
  transect$Longitude,
  transect$Latitude,
  pch = 23,
  bg = transect$color,
  col = "black",
  cex = 0.5,
  lwd = 0.5
)

# island names
text(
  c(min(transect$Longitude[transect$Island == "Barrang Lompo"]), max(transect$Longitude[transect$Island == "K. Keke"])),
  c(min(transect$Latitude[transect$Island == "Barrang Lompo"]) - 0.005, max(transect$Latitude[transect$Island == "K. Keke"]) + 0.005),
  labels = c("Barrang Lompo", "Kodinggareng Keke"),
  cex = 0.8,
  pos = c(2, 4),
  font = 2
)

### end plot ####
dev.off()